autologin library

The public interface of the AutologinPlugin.

Classes

AutologinPlugin
The public interface of the AutologinPlugin. For a quick synchronous check you can check isPlatformSupported. When you need a full report of the Compatibilities you can performCompatibilityChecks. You can check the Compatibilities class for the details. With requestCredentials your saved Credentials can be requested which you need to safe before with saveCredentials.
Compatibilities
The Compatibilities report of the current platform or the browser in case of web.
Credential
Container for your Credentials. Based on your use case all fields can be null.